**********************
*** RECOVERY PRICES
**********************

**** open file recoveryfile.dta that includes recovery values for assets in default

*variables:
*mast_issr_num: company identifier 
*default_type=0 for out-of-court restructuring, =1 for in-court restructuring
*def_recov is the recovery value
*def_date is the default date
*for definition and construction of the other variables, see text

gen size2=size^2

* Table 6 (OOC)
* baseline
local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new  taxdummy cds_flag ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==0), vce(cluster mast_issr_num)

* intangible assets
gen cds_intang=cds_flag*intang_high
local varlist "ln_issue sen_class size lev1 ebitda_ta intang_high ind_med_q_new  taxdummy cds_flag cds_intang ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==0), vce(cluster mast_issr_num)

* sen unsec. debt
gen cds_unsec=cds_flag*unsec_high
local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new taxdummy unsec_high cds_flag cds_unsec ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==0), vce(cluster mast_issr_num)

* bond dispersion 
gen cds_disp=cds_flag*dispers_high
local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new taxdummy dispers_high cds_flag cds_disp  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov  `varlist' if (default_type==0), vce(cluster mast_issr_num)

* cds liq proxy
local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new taxdummy  cds_flag cds_liq_flag  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==0), vce(cluster mast_issr_num)


* Table 7 - IC
local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new  taxdummy cds_flag ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==1), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size lev1 ebitda_ta intang_high ind_med_q_new  taxdummy cds_flag cds_intang ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==1), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new taxdummy unsec_high cds_flag cds_unsec ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist' if (default_type==1), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new taxdummy dispers_high cds_flag cds_disp  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov  `varlist' if (default_type==1), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new taxdummy  cds_flag cds_liq_flag  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==1), vce(cluster mast_issr_num)


***** robustness checks for recovery prices results - 

* controlling for nonlinear size effects - Table B.1, panels B and C
local varlist "ln_issue sen_class size size2 lev1 ebitda_ta tangibility ind_med_q_new taxdummy unsec_high cds_flag cds_unsec ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==0), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size size2 lev1 ebitda_ta tangibility ind_med_q_new taxdummy dispers_high cds_flag cds_disp  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov  `varlist' if (default_type==0 ), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size size2 lev1 ebitda_ta tangibility ind_med_q_new taxdummy  cds_flag cds_liq_flag  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==0), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size size2 lev1 ebitda_ta tangibility ind_med_q_new taxdummy unsec_high cds_flag cds_unsec ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==1), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size size2 lev1 ebitda_ta tangibility ind_med_q_new taxdummy dispers_high cds_flag cds_disp  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov  `varlist' if (default_type==1 ), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size size2 lev1 ebitda_ta tangibility ind_med_q_new taxdummy  cds_flag cds_liq_flag  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==1), vce(cluster mast_issr_num)


* controlling for year 2009 - Table C.1, panels B and C
gen def_year=year(def_date)
gen d_2007=0
replace d_2007=1 if year(def_date)==2007
gen d_2008=0
replace d_2008=1 if year(def_date)==2008
gen d_2009=0
replace d_2009=1 if year(def_date)==2009
gen d_2010=0
replace d_2010=1 if year(def_date)==2010
gen d_2011=0
replace d_2011=1 if year(def_date)==2011

local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new   cds_flag cds_liq_flag  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==0 & d_2009==0), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size lev1 ebitda_ta tangibility ind_med_q_new   cds_flag cds_liq_flag  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==1 & d_2009==0), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size  lev1 ebitda_ta tangibility ind_med_q_new d_2007 d_2008 d_2009 d_2010    cds_flag cds_liq_flag  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==0), vce(cluster mast_issr_num)

local varlist "ln_issue sen_class size  lev1 ebitda_ta tangibility ind_med_q_new d_2007 d_2008 d_2009 d_2010    cds_flag cds_liq_flag  ind_class_1 ind_class_2 ind_class_3 ind_class_4 ind_class_5 ind_class_6 ind_class_7"
regress def_recov `varlist'  if (default_type==1), vce(cluster mast_issr_num)

