******************************************************
*** code for replicating M.Bedendo, L.Cathcart, L.El-Jahel "Distressed Debt Restructuring in the Presence of Credit Default Swaps"
******************************************************

* open stata file outcome.dta 
* this file includes the following variables:

*mast_issr_num: company identifier
*default=0 for out-of-court restructuring, default=1 for in-court restructuring
*cds_flag=0 if no CDS traded on debt, 1 otherwise
*cds_liq_flag=0 if CDS not liquid, 1 otherwise 
*intang_high=1 if company in top tercile for asset intangibility, 0 otherwise
*unsec_high=1 if company in top tercile for unsecured debt, 0 otherwise
*dispers_high=1 if company in top tercile for bond dispersion, 0 otherwise
*default_date is the date of default
*year is the year of default
*for the definition and construction of other variables, refer to the paper  

snapshot save, label("DBASE")

********* summary stats, Table 1
collapse (count) default , by(year)
snapshot restore 1
collapse (count) default if default==0, by(year)
snapshot restore 1
collapse (count) default if default==1, by(year)
snapshot restore 1
collapse (count) size if private_flag==0, by(default)
snapshot restore 1
collapse (count) size if private_flag==1, by(default)
snapshot restore 1
collapse (count) size if cds_flag==0, by(default)
snapshot restore 1
collapse (count) size if cds_flag==1, by(default)
snapshot restore 1
collapse (count) size if cds_liq_flag==1, by(default)
snapshot restore 1

********* summary stats, Tables 2 and 3
global varlist1 "size leverage lev_ind_adj op_income ebitda_ind_adj short_debt_td bank_td public_td secured_td sen_unsec_td subord_td num_tiers num_public "
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist1, unequal by(default)
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist1 if cds_flag==1, unequal by(default)
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist1 if cds_flag==0, unequal by(default)
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist1 , unequal by(cds_flag)

bysort default: centile $varlist1 
bysort default: centile $varlist1 if cds_flag==0
bysort default: centile $varlist1 if cds_flag==1 
bysort cds_flag: centile $varlist1 

************** Appendix Table D.1 Bank characteristics
global varlist2 "perc_tlb perc_sec_bank_debt num_lead num_partic mean_roa mean_change_roa"
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist2, unequal by(default)
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist2 if cds_flag==1, unequal by(default)
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist2 if cds_flag==0, unequal by(default)
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist2 , unequal by(cds_flag)

bysort default: centile $varlist2 
bysort default: centile $varlist2 if cds_flag==0
bysort default: centile $varlist2 if cds_flag==1 
bysort cds_flag: centile $varlist2 
********************************************************

***************
** RESTRUCTURING OUTCOME
***************

* Baseline specification - Table 4
local varlist "cds_flag"
probit default `varlist', vce(robust)

local varlist "size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag"
probit default `varlist', vce(robust)

local varlist "size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag"
probit default `varlist' if cds_flag==1, vce(robust)

local varlist "size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag"
probit default `varlist' if cds_flag==0, vce(robust)
predict prob_pred_3
count if prob_pred_3<=0.5 & default==0 & cds_flag==1
count if prob_pred_3<=0.5 & cds_flag==1
count if prob_pred_3>0.5 & default==1 & cds_flag==1
count if prob_pred_3>0.5 & cds_flag==1
count if prob_pred_3<=0.5 & default==0 & cds_flag==0
count if prob_pred_3<=0.5 & cds_flag==0
count if prob_pred_3>0.5 & default==1 & cds_flag==0
count if prob_pred_3>0.5 & cds_flag==0

gen size_CDS=size*cds_flag
gen lev_CDS=lev_ind_adj*cds_flag
gen secured_CDS=secured_td*cds_flag
gen short_CDS=short_debt_td*cds_flag
gen tiers_CDS=num_tiers*cds_flag
gen tax2_CDS=taxdummy*cds_flag
gen size2=size^2

probit default size size_CDS lev_ind_adj lev_CDS  secured_td secured_CDS short_debt_td short_CDS num_tiers tiers_CDS  taxdummy tax2_CDS cds_flag, vce(robust)
test size_CDS=0
test lev_CDS=0
test secured_CDS
test short_CDS
test tiers_CDS
test tax2_CDS
test (size_CDS=0) (lev_CDS=0) (secured_CDS) (short_CDS) (tiers_CDS)  (tax2_CDS)


* Refinement of the proxy for presence of empty creditors - Table 5
* liquidation costs
gen cds_intang=cds_flag*intang_high
local varlist "size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy intang_high cds_flag cds_intang"
probit default `varlist', vce(robust)

* proportion of senior unsecured debt
gen cds_unsec=cds_flag*unsec_high
local varlist "size lev_ind_adj secured_td  short_debt_td num_tiers  taxdummy unsec_high cds_flag cds_unsec"
probit default `varlist', vce(robust)

* measure of bond dispersion
gen cds_disp=cds_flag*dispers_high 
local varlist "size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy dispers_high cds_flag cds_disp"
probit default `varlist', vce(robust)

* CDS liquidity
local varlist "size lev_ind_adj  secured_td short_debt_td num_tiers taxdummy cds_flag cds_liq_flag"
probit default `varlist', vce(robust)


******** robustness checks on restructuring outcome results

* bootstrapped standard errors - Table A.1
probit default size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag , vce(bootstrap, rep(100))
probit default size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag , vce(bootstrap (_b[cds_flag] + _b[cds_liq_flag]), rep(100))
probit default size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag , vce(bootstrap, rep(300))
probit default size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag , vce(bootstrap (_b[cds_flag] + _b[cds_liq_flag]), rep(300))
probit default size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag , vce(bootstrap, rep(500))
probit default size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag , vce(bootstrap (_b[cds_flag] + _b[cds_liq_flag]), rep(500))
probit default size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag , vce(bootstrap, rep(1000))
probit default size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag , vce(bootstrap (_b[cds_flag] + _b[cds_liq_flag]), rep(1000))

* non-linear effects of firm size - Table B.1
local varlist "size size2 lev_ind_adj secured_td  short_debt_td num_tiers  taxdummy unsec_high cds_flag cds_unsec"
probit default `varlist', vce(robust)

local varlist "size size2 lev_ind_adj secured_td short_debt_td num_tiers  taxdummy dispers_high cds_flag cds_disp"
probit default `varlist', vce(robust)

local varlist "size size2 lev_ind_adj  secured_td short_debt_td num_tiers taxdummy cds_flag cds_liq_flag"
probit default `varlist', vce(robust)

* controlling for 2009 events - Table C.1
local varlist "size lev_ind_adj secured_td short_debt_td num_tiers  taxdummy cds_flag cds_liq_flag"
probit default `varlist' if d_2009==0, vce(robust)

gen d_2007=0
replace d_2007=1 if year==2007
drop d_2010
gen d_2010=0
replace d_2010=1 if year==2010
gen d_2011=0
replace d_2011=1 if year==2011
local varlist "size lev_ind_adj secured_td short_debt_td num_tiers  d_2007 d_2008 d_2009 d_2010 cds_flag cds_liq_flag"
probit default `varlist', vce(robust)


*******************
** SAMPLE MATCHING - TABLE 8
*******************

*Panel A
nnmatch default cds_flag size lev_ind_adj sen_unsec_general tangibility short_debt_td bond_dispersion ,  biasadj(bias) tc(att) robust(6) keep(matched_sample) replace

*the following file includes the matched and control samples for Panel A
* open file matched_sample.dta 

ren default_0 default0
ren size_0m size0
ren lev_ind_adj_0m lev_ind_adj0
ren  sen_unsec_general_0m sen_unsec_general0
ren  tangibility_0m tangibility0 
ren short_debt_td_0m short_debt_td0
ren bond_dispersion_0m bond_dispersion0

ren default_1 default1
ren size_1m size1
ren lev_ind_adj_1m lev_ind_adj1
ren  sen_unsec_general_1m sen_unsec_general1
ren  tangibility_1m tangibility1 
ren short_debt_td_1m short_debt_td1
ren bond_dispersion_1m bond_dispersion1
drop default size lev_ind_adj sen_unsec_general tangibility short_debt_td bond_dispersion

reshape long default size lev_ind_adj sen_unsec_general tangibility short_debt_td bond_dispersion, i(id) j(orig_control)

global varlist1 "default size lev_ind_adj sen_unsec_general tangibility short_debt_td bond_dispersion "
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist1 , unequal by(orig_control)
makematrix, from(r(z) r(N_1) r(N_2)) format(%4.3f) label: ranksum  $varlist1 , by(orig_control)
bysort orig_control: centile $varlist1 

*Panel B
nnmatch default cds_flag size lev_ind_adj sen_unsec_general tangibility short_debt_td bond_dispersion if cds_liq_flag==0,  biasadj(bias) tc(att) robust(6) keep(matched_sample_illiq) replace

*the following file includes the matched and control samples for Panel B
* open file matched_sample_illiq.dta
ren default_0 default0
ren size_0m size0
ren lev_ind_adj_0m lev_ind_adj0
ren  sen_unsec_general_0m sen_unsec_general0
ren  tangibility_0m tangibility0 
ren short_debt_td_0m short_debt_td0
ren bond_dispersion_0m bond_dispersion0
ren default_1 default1
ren size_1m size1
ren lev_ind_adj_1m lev_ind_adj1
ren  sen_unsec_general_1m sen_unsec_general1
ren  tangibility_1m tangibility1 
ren short_debt_td_1m short_debt_td1
ren bond_dispersion_1m bond_dispersion1
drop default size lev_ind_adj sen_unsec_general tangibility short_debt_td bond_dispersion

reshape long default size lev_ind_adj sen_unsec_general tangibility short_debt_td bond_dispersion, i(id) j(orig_control)

global varlist1 "default size lev_ind_adj sen_unsec_general tangibility short_debt_td bond_dispersion "
makematrix, from(r(mu_1) r(sd_1) r(N_1) r(mu_2) r(sd_2) r(N_2) r(t) r(p)) format(%4.3f) label: ttest $varlist1 , unequal by(orig_control)
makematrix, from(r(z) r(N_1) r(N_2)) format(%4.3f) label: ranksum  $varlist1 , by(orig_control)
bysort orig_control: centile $varlist1 



